@@ -13,7 +13,7 @@ use Exporter ();
 
 use Validation::Class::Prototype;
 
-our $VERSION = '7.900026'; # VERSION
+our $VERSION = '7.900027'; # VERSION
 
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(
@@ -512,7 +512,7 @@ Validation::Class - Powerful Data Validation Framework
 
 =head1 VERSION
 
-version 7.900026
+version 7.900027
 
 =head1 SYNOPSIS
 
@@ -653,42 +653,34 @@ per instance. See the list of core directives, L<Validation::Class::Directives>,
 or review L<Validation::Class::Directive> for insight into creating your own
 CPAN installable directives.
 
-    package MyApp::Directives;
-
-    use Validation::Class 'directive';
-
-    use Data::Validate::Email;
-
-    directive 'isa_email_address' => sub {
-
-        my ($self, $field, $param) = @_;
-
-        my $validator = Data::Validate::Email->new;
-
-        unless ($validator->is_email($param)) {
-
-            my $handle = $field->label || $field->name;
-
-            $field->errors->add("$handle must be a valid email address");
-
-            return 0;
-
-        }
-
-        return 1;
-
-    };
-
     package MyApp::Person;
 
     use Validate::Class;
 
-    use MyApp::Directives;
+    # define a custom class-level directive
+    directive 'blacklisted' => sub {
+        my ($self, $field, $param) = @_;
+
+        if (defined $field->{blacklisted} && defined $param) {
+            if ($field->{required} || $param) {
+                if (exists_in_blacklist($field->{blacklisted}, $param)) {
+                    my $handle = $field->label || $field->name;
+                    $field->errors->add("$handle has been blacklisted");
+                    return 0;
+                }
+            }
+        }
+
+        return 1;
+    };
 
     field 'email_address' => {
-        isa_email_address => 1
+        email => 1,
+        blacklisted => '/path/to/blacklsit'
     };
 
+
+
     1;
 
 The directive keyword takes two arguments, the name of the directive and a
